==> openshift-model-5.7.4-sources.jar: io/fabric8/openshift/api/model/ScopeRestrictionFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ScopeRestrictionFluent<A extends io.fabric8.openshift.api.model.ScopeRestrictionFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildClusterRole instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ClusterRoleScopeRestriction getClusterRole();
  public io.fabric8.openshift.api.model.ClusterRoleScopeRestriction buildClusterRole();
  public A withClusterRole(io.fabric8.openshift.api.model.ClusterRoleScopeRestriction clusterRole);
  public java.lang.Boolean hasClusterRole();
  public io.fabric8.openshift.api.model.ScopeRestrictionFluent.ClusterRoleNested<A> withNewClusterRole();
  public io.fabric8.openshift.api.model.ScopeRestrictionFluent.ClusterRoleNested<A> withNewClusterRoleLike(io.fabric8.openshift.api.model.ClusterRoleScopeRestriction item);
  public io.fabric8.openshift.api.model.ScopeRestrictionFluent.ClusterRoleNested<A> editClusterRole();
  public io.fabric8.openshift.api.model.ScopeRestrictionFluent.ClusterRoleNested<A> editOrNewClusterRole();
  public io.fabric8.openshift.api.model.ScopeRestrictionFluent.ClusterRoleNested<A> editOrNewClusterRoleLike(io.fabric8.openshift.api.model.ClusterRoleScopeRestriction item);
  public A addToLiterals(java.lang.Integer index,java.lang.String item);
  public A setToLiterals(java.lang.Integer index,java.lang.String item);
  public A addToLiterals(java.lang.String... items);
  public A addAllToLiterals(java.util.Collection<java.lang.String> items);
  public A removeFromLiterals(java.lang.String... items);
  public A removeAllFromLiterals(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getLiterals();
  public java.lang.String getLiteral(java.lang.Integer index);
  public java.lang.String getFirstLiteral();
  public java.lang.String getLastLiteral();
  public java.lang.String getMatchingLiteral(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingLiteral(java.util.function.Predicate<java.lang.String> predicate);
  public A withLiterals(java.util.List<java.lang.String> literals);
  public A withLiterals(java.lang.String... literals);
  public java.lang.Boolean hasLiterals();
  public A addNewLiteral(java.lang.String arg0);
  public interface ClusterRoleNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ClusterRoleScopeRestrictionFluent<io.fabric8.openshift.api.model.ScopeRestrictionFluent.ClusterRoleNested<N>>{
    public N and();
    public N endClusterRole();
    
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/ScopeRestrictionFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ScopeRestrictionFluent<A extends io.fabric8.openshift.api.model.ScopeRestrictionFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildClusterRole instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ClusterRoleScopeRestriction getClusterRole();
  public io.fabric8.openshift.api.model.ClusterRoleScopeRestriction buildClusterRole();
  public A withClusterRole(io.fabric8.openshift.api.model.ClusterRoleScopeRestriction clusterRole);
  public java.lang.Boolean hasClusterRole();
  public io.fabric8.openshift.api.model.ScopeRestrictionFluent.ClusterRoleNested<A> withNewClusterRole();
  public io.fabric8.openshift.api.model.ScopeRestrictionFluent.ClusterRoleNested<A> withNewClusterRoleLike(io.fabric8.openshift.api.model.ClusterRoleScopeRestriction item);
  public io.fabric8.openshift.api.model.ScopeRestrictionFluent.ClusterRoleNested<A> editClusterRole();
  public io.fabric8.openshift.api.model.ScopeRestrictionFluent.ClusterRoleNested<A> editOrNewClusterRole();
  public io.fabric8.openshift.api.model.ScopeRestrictionFluent.ClusterRoleNested<A> editOrNewClusterRoleLike(io.fabric8.openshift.api.model.ClusterRoleScopeRestriction item);
  public A addToLiterals(java.lang.Integer index,java.lang.String item);
  public A setToLiterals(java.lang.Integer index,java.lang.String item);
  public A addToLiterals(java.lang.String... items);
  public A addAllToLiterals(java.util.Collection<java.lang.String> items);
  public A removeFromLiterals(java.lang.String... items);
  public A removeAllFromLiterals(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getLiterals();
  public java.lang.String getLiteral(java.lang.Integer index);
  public java.lang.String getFirstLiteral();
  public java.lang.String getLastLiteral();
  public java.lang.String getMatchingLiteral(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingLiteral(java.util.function.Predicate<java.lang.String> predicate);
  public A withLiterals(java.util.List<java.lang.String> literals);
  public A withLiterals(java.lang.String... literals);
  public java.lang.Boolean hasLiterals();
  public A addNewLiteral(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ClusterRoleNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ClusterRoleScopeRestrictionFluent<io.fabric8.openshift.api.model.ScopeRestrictionFluent.ClusterRoleNested<N>>{
    public N and();
    public N endClusterRole();
    
  }
  
}
